/***************************************************************************
*   Copyright (C) 2005 by Karl Erlandsen #c1198379                        *
*   c1198379@bmth.ac.uk                                                   *
*                                                                         *
* This file contains definitions for the tripletMatrix class. This class  *
* hold a matrix that begins in triplet form. Triplets of values can be    *
* added to it, and then once all the data has been added it can be        *
* converted to a compressed column form matrix instead. Note that once it *
* has been converted, it can no longer be edited. This class is used to   *
* store weighting values for the image to be filtered, before conversion  *
* and use with UMFPack.                                                   *
*                                                                         *
* Not for use without the authors permission				  *
***************************************************************************/

#ifndef TRIPLETMATRIX_H
#define TRIPLETMATRIX_H

/*
 * This is a class to hold a matrix that begins in triplet form. Triplets of values can be
 * added to it via "addTriplet()", and then once all the necessary data has been added it
 * can be converted to a compressed column form matrix instead. Note that once it has been
 * converted, it can no longer be edited.
 */

class tripletMatrix
{
	public:
		tripletMatrix(int _width, int _height, int _windowSize);
		~tripletMatrix();
	
		/*arrays of values for when our matrix is in triplet form*/
		int *tripletI, *tripletJ;
		double *tripletX;
	
		/*arrays of values for when our matrix is in compressed column form*/
		int *columnP, *columnI;
		double *columnX;
	
		/*Function to add a triplet of values to our matrix when it's in triplet form*/
		void addTriplet(double value, int i, int j);
		/*Function to convert our matrix into compressed column notation*/
		void convertToCompressedColumn();
	
	private:
		/*Size of the image this matrix is for*/
		int width, height;
		/*Size of the imaging window taken for each sample. This is needed for matrix conversion*/
		int windowSize;
		/*How many triplet values have been added*/
		int n;
		/*What state this matrix is in - triplet or column? 1 = triplet, 0 = column*/
		short isTriplet;
};

#endif
