/***************************************************************************
 *   Copyright (C) 2005 by Karl Erlandsen #c1198379                        *
 *   c1198379@bmth.ac.uk                                                   *
 *                                                                         *
* This file contains definitions for the class "yuvimage", which loads in  *
* image data through ImageMagick and provides the user with an interface to*
* access the data as either YUV or RGB double floating point arrays. This  *
* class is used to load, store, and finally display processed data through *
* an OpenGL texture.                                                       *
 *                                                                         *
 * Not for use without the authors permission				   *
 ***************************************************************************/
 
#ifndef YUVIMAGE_H
#define YUVIMAGE_H

#include <iostream>	//std::string
#include <GL/gl.h>	//GLuint

/* 
 * Simple class to load in an image, convert it between RGB and YUV, and display
 * it in an OpenGL texture if needs be. Channels are stored seperately from each
 * other.
 */
class yuvimage
{
public:
    yuvimage();
    yuvimage(const int width_, const int height_);
    yuvimage(const std::string Filename);

    ~yuvimage();

    void loadImage(const std::string Filename);
    void RGBtoYUV();
    void YUVtoRGB();
    void makeDrawData();

    int width, height;
    double *r, *g, *b, *y, *u, *v;
    GLuint texture;
    short isRGB;

private:
    void initMembers();
    void freePixmap();
};

#endif
